==> igniteui-webcomponents-core-3.5.0.tgz: package/esm2015/lib/ColumnSortDescriptionDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { ColumnSortDescriptionDescription } from "./ColumnSortDescriptionDescription";
/**
 * @hidden
 */
export let ColumnSortDescriptionDescriptionMetadata = /*@__PURE__*/ (() => {
    class ColumnSortDescriptionDescriptionMetadata extends Base {
        static b(a) {
            if (ColumnSortDescriptionDescriptionMetadata.a == null) {
                ColumnSortDescriptionDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                ColumnSortDescriptionDescriptionMetadata.c(ColumnSortDescriptionDescriptionMetadata.a);
            }
            if (a.j(ColumnSortDescriptionDescriptionMetadata.a)) {
                return;
            }
            a.y(ColumnSortDescriptionDescriptionMetadata.a);
        }
        static c(a) {
            a.item("Field", "String");
            a.item("SortDirection", "ExportedType:string:ListSortDirection");
            a.item("SortDirection@names", "Ascending;Descending");
        }
        static d(a) {
            ColumnSortDescriptionDescriptionMetadata.b(a);
            a.aa("ColumnSortDescription", () => new ColumnSortDescriptionDescription());
            a.z("ColumnSortDescription", ColumnSortDescriptionDescriptionMetadata.a);
        }
    }
    ColumnSortDescriptionDescriptionMetadata.$t = /*@__PURE__*/ markType(ColumnSortDescriptionDescriptionMetadata, 'ColumnSortDescriptionDescriptionMetadata');
    ColumnSortDescriptionDescriptionMetadata.a = null;
    return ColumnSortDescriptionDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/ColumnSortDescriptionDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { ColumnSortDescriptionDescription } from "./ColumnSortDescriptionDescription";
/**
 * @hidden
 */
export let ColumnSortDescriptionDescriptionMetadata = /*@__PURE__*/ (() => {
    class ColumnSortDescriptionDescriptionMetadata extends Base {
        static b(a) {
            if (ColumnSortDescriptionDescriptionMetadata.a == null) {
                ColumnSortDescriptionDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                ColumnSortDescriptionDescriptionMetadata.c(ColumnSortDescriptionDescriptionMetadata.a);
            }
            if (a.k(ColumnSortDescriptionDescriptionMetadata.a)) {
                return;
            }
            a.aa(ColumnSortDescriptionDescriptionMetadata.a);
        }
        static c(a) {
            a.item("Field", "String");
            a.item("SortDirection", "ExportedType:string:ListSortDirection");
            a.item("SortDirection@names", "Ascending;Descending");
        }
        static d(a) {
            ColumnSortDescriptionDescriptionMetadata.b(a);
            a.ac("ColumnSortDescription", () => new ColumnSortDescriptionDescription());
            a.ab("ColumnSortDescription", ColumnSortDescriptionDescriptionMetadata.a);
        }
    }
    ColumnSortDescriptionDescriptionMetadata.$t = /*@__PURE__*/ markType(ColumnSortDescriptionDescriptionMetadata, 'ColumnSortDescriptionDescriptionMetadata');
    ColumnSortDescriptionDescriptionMetadata.a = null;
    return ColumnSortDescriptionDescriptionMetadata;
})();
